@@ -33,6 +33,11 @@ def onehost(task):
     return task
 
 
+def firsthost(task):
+    task.__firsthost__ = True
+    return task
+
+
 class DeployTasks(Tasks):
     SETTINGS = None
 
@@ -62,13 +67,6 @@ class DeployTasks(Tasks):
     def get_namespace(cls):
         return cls.SETTINGS.NAME
 
-    @property
-    def listen_ip(self):
-        """Listen ip for service private or public avalability"""
-        if getattr(self.settings, 'listen_private_ip', False):
-            return self.private_ip
-        return self.public_ip
-
     def get_all_manager_tasks(self, name: str = ''):
         for task_class in self._manager.tasks.values():
             task_name = task_class.get_namespace()
@@ -203,16 +201,26 @@ class DeployTasks(Tasks):
             await self._rmrf(path)
         await self._run(f'mkdir -p {path}')
 
-    async def _upload(self, local_path: Path, path: Path = None, exclude=None):
+    async def _upload(
+            self, local_path: Path, path: Path = None,
+            exclude=None, include=None, from_host=False):
         exclude = [f"--exclude '{path}'" for path in exclude or []]
         exclude = ' '.join(exclude)
         dir_slash = '/' if local_path.is_dir() else ''
         if not path:
             path = Path('~/', local_path.name)
-        if local_path.exists():
+        paths = [
+            f"{local_path}{dir_slash}",
+            f"{self.user}@{self.public_ip}:{path}"
+        ]
+        if from_host:
+            paths.reverse()
+        paths = ' '.join(paths)
+        include = ' '.join(f"--include '{i}'" for i in include or [])
+        if local_path.exists() or from_host:
             await self._local(
-                f'rsync -rave "ssh -p {self.port}" --delete {exclude} '
-                f'{local_path}{dir_slash} {self.user}@{self.public_ip}:{path}'
+                f'rsync -rave "ssh -p {self.port}" --delete {include} '
+                f'{exclude} {paths}'
             )
 
     async def _upload_template(
@@ -252,6 +260,12 @@ class DeployTasks(Tasks):
         await self._rmrf(archive)
         await self._rmrf(archive_dir)
 
+    async def _append(self, content, dest_file: Path):
+        await self._run(
+            f'grep -qxF "{content}" {dest_file} || '
+            f'echo "{content}" >> {dest_file}'
+        )
+
     @register
     @onehost
     async def ssh(self):
